@@ -1,6 +1,6 @@
 package Mojo::IOLoop::ReadWriteProcess;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 use Mojo::Base 'Mojo::EventEmitter';
 use Mojo::File 'path';
@@ -189,6 +189,15 @@ sub _fork {
 
     my $return;
     my $internal_err;
+
+    if ($self->_internal_err) {
+      $internal_err
+        = $self->_internal_err->isa("IO::Pipe::End") ?
+        $self->_internal_err
+        : $self->_internal_err->writer();
+      $internal_err->autoflush(1);
+    }
+
     if ($self->_internal_return) {
       $return
         = $self->_internal_return->isa("IO::Pipe::End")
@@ -198,18 +207,7 @@ sub _fork {
       $return->autoflush(1);
     }
     else {
-      $self->_new_err("Can't setup return status pipe");
-    }
-
-    if ($self->_internal_err) {
-      $internal_err
-        = $self->_internal_err->isa("IO::Pipe::End") ?
-        $self->_internal_err
-        : $self->_internal_err->writer();
-      $internal_err->autoflush(1);
-    }
-    else {
-      $self->_new_err("Can't setup error pipe");
+      eval { $internal_err->write("Can't setup return status pipe") };
     }
 
     # Set pipes to redirect STDIN/STDOUT/STDERR + channels if desired
@@ -300,9 +298,9 @@ sub wait {
 
 sub wait_stop   { shift->wait->stop }
 sub errored     { !!@{shift->error} ? 1 : 0 }
-sub exit_status { $_[0]->_status ? shift->_status >> 8 : undef }
+sub exit_status { defined $_[0]->_status ? shift->_status >> 8 : undef }
 sub restart     { $_[0]->is_running ? $_[0]->stop->start : $_[0]->start; }
-sub is_running  { return $_[0]->process_id ? kill 0 => $_[0]->process_id : 0; }
+sub is_running  { $_[0]->process_id ? kill 0 => $_[0]->process_id : 0; }
 
 sub write_pidfile {
   my ($self, $pidfile) = @_;
